FedaTransactionRequest class

Constructors

FedaTransactionRequest({required String description, required double amount, required String clienMail, required Map phone_number})
FedaTransactionRequest.fromJson(String source)
factory
FedaTransactionRequest.fromMap(Map<String, dynamic> map)
factory

Properties

amount ↔ double
getter/setter pair
clienMail ↔ String
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
phone_number ↔ Map
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? description, double? amount, String? clienMail, Map? phone_number}) → FedaTransactionRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant FedaTransactionRequest other) → bool
The equality operator.
override