FedaTransaction class

Constructors

FedaTransaction({int? id, String? reference, String? description, double? amount, String? status, String? mode, double? amount_debited, String? receipt_url, String? operator_fees, String? approved_at, String? created_at, String? updated_at, String? canceled_at, String? declined_at, String? refunded_at, String? transferred_at})
FedaTransaction.fromJson(String source)
factory
FedaTransaction.fromMap(dynamic map)
factory

Properties

amount ↔ double?
getter/setter pair
amount_debited ↔ double?
getter/setter pair
approved_at ↔ String?
getter/setter pair
canceled_at ↔ String?
getter/setter pair
created_at ↔ String?
getter/setter pair
declined_at ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ int?
getter/setter pair
mode ↔ String?
getter/setter pair
operator_fees ↔ String?
getter/setter pair
receipt_url ↔ String?
getter/setter pair
reference ↔ String?
getter/setter pair
refunded_at ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair
transferred_at ↔ String?
getter/setter pair
updated_at ↔ String?
getter/setter pair

Methods

copyWith({int? id, String? reference, String? description, double? amount, String? status, String? mode, double? amount_debited, String? receipt_url, String? operator_fees, String? approved_at, String? created_at, String? updated_at, String? canceled_at, String? declined_at, String? refunded_at, String? transferred_at}) → FedaTransaction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant FedaTransaction other) → bool
The equality operator.
override